diff --git a/Makefile b/Makefile
index e8cc4436..ea91b9be 100644
--- a/Makefile
+++ b/Makefile
@@ -34,7 +34,7 @@ CRT_OBJS = $(filter obj/crt/%,$(ALL_OBJS))
 
 AOBJS = $(LIBC_OBJS)
 LOBJS = $(LIBC_OBJS:.o=.lo)
-GENH = obj/include/bits/alltypes.h obj/include/bits/syscall.h
+GENH = obj/include/bits/alltypes.h obj/include/bits/syscall.h obj/include/features.h
 GENH_INT = obj/src/internal/version.h
 IMPH = $(addprefix $(srcdir)/, src/internal/stdio_impl.h src/internal/pthread_impl.h src/internal/locale_impl.h src/internal/libc.h)
 
@@ -95,6 +95,17 @@ $(ALL_LIBS) $(ALL_TOOLS) $(ALL_OBJS) $(ALL_OBJS:%.o=%.lo) $(GENH) $(GENH_INT): |
 $(OBJ_DIRS):
 	mkdir -p $@
 
+MUSL_VERSION:=$(shell cd $(srcdir) && sh tools/version.sh)
+empty:=
+space:=$(empty) $(empty)
+musl_ver_parts:=$(subst -git-,$(space),$(subst .,$(space),$(MUSL_VERSION)))
+MUSL_MAJOR:=$(word 1, $(musl_ver_parts))
+MUSL_MINOR:=$(word 2, $(musl_ver_parts))
+MUSL_PATCH:=$(word 3, $(musl_ver_parts))
+
+obj/include/features.h: $(srcdir)/include/features.h.in $(wildcard $(srcdir)/VERSION $(srcdir)/.git)
+	sed -e "s/@MUSL_MAJOR@/$(MUSL_MAJOR)/g;s/@MUSL_MINOR@/$(MUSL_MINOR)/g;s/@MUSL_PATCH@/$(MUSL_PATCH)/g" $< > $@
+
 obj/include/bits/alltypes.h: $(srcdir)/arch/$(ARCH)/bits/alltypes.h.in $(srcdir)/include/alltypes.h.in $(srcdir)/tools/mkalltypes.sed
 	sed -f $(srcdir)/tools/mkalltypes.sed $(srcdir)/arch/$(ARCH)/bits/alltypes.h.in $(srcdir)/include/alltypes.h.in > $@
 
@@ -103,7 +114,7 @@ obj/include/bits/syscall.h: $(srcdir)/arch/$(ARCH)/bits/syscall.h.in
 	sed -n -e s/__NR_/SYS_/p < $< >> $@
 
 obj/src/internal/version.h: $(wildcard $(srcdir)/VERSION $(srcdir)/.git)
-	printf '#define VERSION "%s"\n' "$$(cd $(srcdir); sh tools/version.sh)" > $@
+	printf '#define VERSION "%s"\n' "$(MUSL_VERSION)" > $@
 
 obj/src/internal/version.o obj/src/internal/version.lo: obj/src/internal/version.h
 
@@ -209,6 +220,9 @@ $(DESTDIR)$(includedir)/bits/%: obj/include/bits/%
 $(DESTDIR)$(includedir)/%: $(srcdir)/include/%
 	$(INSTALL) -D -m 644 $< $@
 
+$(DESTDIR)$(includedir)/%: obj/include/%
+	$(INSTALL) -D -m 644 $< $@
+
 $(DESTDIR)$(LDSO_PATHNAME): $(DESTDIR)$(libdir)/libc.so
 	$(INSTALL) -D -l $(libdir)/libc.so $@ || true
 
diff --git a/include/features.h b/include/features.h.in
similarity index 80%
rename from include/features.h
rename to include/features.h.in
index 85cfb72a..07662804 100644
--- a/include/features.h
+++ b/include/features.h.in
@@ -1,6 +1,13 @@
 #ifndef _FEATURES_H
 #define _FEATURES_H
 
+#define __MUSL__       @MUSL_MAJOR@
+#define __MUSL_MINOR__ @MUSL_MINOR@
+#define __MUSL_PATCH__ @MUSL_PATCH@
+
+#define __MUSL_PREREQ(maj, min) \
+  ((__MUSL__ << 16) + __MUSL_MINOR >= ((maj) << 16) + (min))
+
 #if defined(_ALL_SOURCE) && !defined(_GNU_SOURCE)
 #define _GNU_SOURCE 1
 #endif
